Mercedes-Benz GL 350 D 4Matic Bluetec | BRC Autocentrs

- 245
- Pēdējoreiz atjaunots 2 d.

# Mercedes-Benz GL 350

## D 4Matic Bluetec (Nr: 107)

- Rīgā
- 220483 km
- 2013 g.
- 3.0l Dīzelis
- Garantija

Cena
€ 33500
PVN nav piemērojams
Līzinga ikmēneša maksājums
€ 518
€ mēn.

###### Magnuss Jenčiuss

- +371 264 37 555
- magnuss.jenciuss@brc.lv

Līzinga kalkulators
Cena
Nomas ikmēneša maksājums
12
24
36
48
60
60
Depozīts % €3350
0
20
50
70
100
10 %
Procenti %
Kasko
Jā
555 €/mėn.
Fiziska persona
JURIDISKA PERSONA
Automašīnu maiņa
Transporta līdzeklis atrodas

### Magnuss Jenčiuss

+371 264 37 555

magnuss.jenciuss@brc.lv

## Mercedes-Benz GL 350

## D 4Matic Bluetec

Vispārīga informācija

- 2013 g.
- 220483 km
- 3.0l Dīzelis
- Automātiskā
- 190 Kw (258 HP)
- Pilnpiedziņas
- Apvidus
- 4
- Garantija

Virsbūves nr: WDC1668241A317435

Komplektācija
Audio, Video, Komunikācijas
Komforta aprīkojums
Salons
Gaismas
Apvidus
Cits aprīkojums
Drošības un pretzagļu iekārtas
Sēdvietas
Riepas un Diski
Līzings Mainīt SAZINIETIES

Informējam, ka www.lv.brcauto.eu interneta vietnes darbības nodrošināšanai un lietotāju apmeklētāju statistikas apkopošanai izvieto sīkdatnes, sīkāka informācija par izvietotajām sīkdatnēm un darbībām, kā atspējot sīkdatnes pieejama BRC Auto Sīkdatņu politikā.
Sīkdatņu politika

Esmu informēts/-a